pub struct U8Vec { /* private fields */ }Implementations
Sourceimpl U8Vec
impl U8Vec
pub fn new() -> U8Vec
pub fn with_capacity(cap: usize) -> Self
pub const fn from_const_slice(input: &'static [u8]) -> Self
pub fn from_vec(input: Vec<u8>) -> Self
pub fn iter(&self) -> Iter<'_, u8>
pub const fn len(&self) -> usize
pub const fn capacity(&self) -> usize
pub const fn is_empty(&self) -> bool
Sourcepub fn get(&self, index: usize) -> Option<&u8>
pub fn get(&self, index: usize) -> Option<&u8>
Returns a reference to the element at the given index (Rust-only, inline).
Sourcepub fn c_get(&self, index: usize) -> OptionU8
pub fn c_get(&self, index: usize) -> OptionU8
C-API compatible get function. Returns a copy of the element at the given index. Returns None if the index is out of bounds.
Sourcepub fn as_slice(&self) -> &[u8] ⓘ
pub fn as_slice(&self) -> &[u8] ⓘ
Returns the vec as a Rust slice (Rust-only, not C-API compatible).
Sourcepub fn as_c_slice(&self) -> U8VecSlice
pub fn as_c_slice(&self) -> U8VecSlice
Returns a C-compatible slice of the entire Vec.
Sourcepub fn as_c_slice_range(&self, start: usize, end: usize) -> U8VecSlice
pub fn as_c_slice_range(&self, start: usize, end: usize) -> U8VecSlice
Returns a C-compatible slice of a range within the Vec. If the range is out of bounds, it is clamped to the valid range.
Sourceimpl U8Vec
impl U8Vec
pub fn as_mut_ptr(&mut self) -> *mut u8
pub fn sort_by<F: FnMut(&u8, &u8) -> Ordering>(&mut self, compare: F)
pub fn push(&mut self, value: u8)
pub fn insert(&mut self, index: usize, element: u8)
pub fn remove(&mut self, index: usize)
pub fn pop(&mut self) -> Option<u8>
pub fn iter_mut(&mut self) -> IterMut<'_, u8>
pub fn into_iter(self) -> IntoIter<u8>
pub fn append(&mut self, other: &mut Self)
pub fn reserve(&mut self, additional: usize)
pub fn truncate(&mut self, len: usize)
pub fn retain<F>(&mut self, f: F)
Sourceimpl U8Vec
impl U8Vec
pub fn from_copy_on_write(input: Cow<'static, [u8]>) -> U8Vec
Sourcepub unsafe fn copy_from_ptr(ptr: *const u8, len: usize) -> Self
pub unsafe fn copy_from_ptr(ptr: *const u8, len: usize) -> Self
Copies elements from a C array pointer into a new Vec.
Safety
ptrmust be valid for readinglenelements- The memory must be properly aligned for
$struct_type - The elements are cloned, so
$struct_typemust implementClone
Sourcepub fn clone_self(&self) -> Self
pub fn clone_self(&self) -> Self
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated
Sourcepub fn into_library_owned_vec(self) -> Vec<u8> ⓘ
pub fn into_library_owned_vec(self) -> Vec<u8> ⓘ
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated