#[repr(C)]pub struct CssRuleBlock {
pub path: CssPath,
pub declarations: CssDeclarationVec,
pub conditions: DynamicSelectorVec,
pub priority: u8,
}Expand description
One block of rules that applies a bunch of rules to a “path” in the style, i.e.
div#myid.myclass -> { ("justify-content", "center") }
The conditions field contains @media/@lang/etc. conditions that must ALL be
satisfied for this rule block to apply (from enclosing @-rule blocks).
Fields
path: CssPathThe css path (full selector) of the style ruleset
declarations: CssDeclarationVec"justify-content: center" =>
CssDeclaration::Static(CssProperty::JustifyContent(LayoutJustifyContent::Center))
conditions: DynamicSelectorVecConditions from enclosing @-rules (@media, @lang, etc.) that must ALL be satisfied for this rule block to apply. Empty = unconditional.
priority: u8Layer priority. See rule_priority for slot allocation.
0 = UA / framework, 20 = author CSS (default), higher = wins.
Sort key combined with selector specificity in sort_by_specificity.
Implementations
Sourceimpl CssRuleBlock
impl CssRuleBlock
pub fn new(path: CssPath, declarations: Vec<CssDeclaration>) -> Self
pub fn with_conditions( path: CssPath, declarations: Vec<CssDeclaration>, conditions: Vec<DynamicSelector>, ) -> Self