pub struct CssVec { /* private fields */ }Implementations
Sourceimpl CssVec
impl CssVec
pub fn new() -> CssVec
pub fn with_capacity(cap: usize) -> Self
pub const fn from_const_slice(input: &'static [Css]) -> Self
pub fn from_vec(input: Vec<Css>) -> Self
pub fn iter(&self) -> Iter<'_, Css>
pub const fn len(&self) -> usize
pub const fn capacity(&self) -> usize
pub const fn is_empty(&self) -> bool
Sourcepub fn get(&self, index: usize) -> Option<&Css>
pub fn get(&self, index: usize) -> Option<&Css>
Returns a reference to the element at the given index (Rust-only, inline).
Sourcepub fn c_get(&self, index: usize) -> OptionCss
pub fn c_get(&self, index: usize) -> OptionCss
C-API compatible get function. Returns a copy of the element at the given index. Returns None if the index is out of bounds.
Sourcepub fn as_slice(&self) -> &[Css]
pub fn as_slice(&self) -> &[Css]
Returns the vec as a Rust slice (Rust-only, not C-API compatible).
Sourcepub fn as_c_slice(&self) -> CssVecSlice
pub fn as_c_slice(&self) -> CssVecSlice
Returns a C-compatible slice of the entire Vec.
Sourcepub fn as_c_slice_range(&self, start: usize, end: usize) -> CssVecSlice
pub fn as_c_slice_range(&self, start: usize, end: usize) -> CssVecSlice
Returns a C-compatible slice of a range within the Vec. If the range is out of bounds, it is clamped to the valid range.
Sourceimpl CssVec
impl CssVec
pub fn as_mut_ptr(&mut self) -> *mut Css
pub fn sort_by<F: FnMut(&Css, &Css) -> Ordering>(&mut self, compare: F)
pub fn push(&mut self, value: Css)
pub fn insert(&mut self, index: usize, element: Css)
pub fn remove(&mut self, index: usize)
pub fn pop(&mut self) -> Option<Css>
pub fn iter_mut(&mut self) -> IterMut<'_, Css>
pub fn into_iter(self) -> IntoIter<Css>
pub fn append(&mut self, other: &mut Self)
pub fn reserve(&mut self, additional: usize)
pub fn truncate(&mut self, len: usize)
pub fn retain<F>(&mut self, f: F)
Sourceimpl CssVec
impl CssVec
pub fn from_copy_on_write(input: Cow<'static, [Css]>) -> CssVec
Sourcepub unsafe fn copy_from_ptr(ptr: *const Css, len: usize) -> Self
pub unsafe fn copy_from_ptr(ptr: *const Css, len: usize) -> Self
Copies elements from a C array pointer into a new Vec.
Safety
ptrmust be valid for readinglenelements- The memory must be properly aligned for
$struct_type - The elements are cloned, so
$struct_typemust implementClone
Sourcepub fn clone_self(&self) -> Self
pub fn clone_self(&self) -> Self
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated
Sourcepub fn into_library_owned_vec(self) -> Vec<Css>
pub fn into_library_owned_vec(self) -> Vec<Css>
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated