pub struct KeyframesVec { /* private fields */ }Implementations
Sourceimpl KeyframesVec
impl KeyframesVec
pub const fn new() -> KeyframesVec
pub fn with_capacity(cap: usize) -> Self
pub const fn from_const_slice(input: &'static [Keyframes]) -> Self
pub const fn from_vec(input: Vec<Keyframes>) -> Self
pub fn iter(&self) -> Iter<'_, Keyframes> ⓘ
pub const fn len(&self) -> usize
pub const fn capacity(&self) -> usize
pub const fn is_empty(&self) -> bool
Sourcepub fn get(&self, index: usize) -> Option<&Keyframes>
pub fn get(&self, index: usize) -> Option<&Keyframes>
Returns a reference to the element at the given index (Rust-only, inline).
Sourcepub fn c_get(&self, index: usize) -> OptionKeyframes
pub fn c_get(&self, index: usize) -> OptionKeyframes
C-API compatible get function. Returns a copy of the element at the given index. Returns None if the index is out of bounds.
Sourcepub fn as_slice(&self) -> &[Keyframes]
pub fn as_slice(&self) -> &[Keyframes]
Returns the vec as a Rust slice (Rust-only, not C-API compatible).
Sourcepub const fn as_c_slice(&self) -> KeyframesVecSlice
pub const fn as_c_slice(&self) -> KeyframesVecSlice
Returns a C-compatible slice of the entire Vec.
Sourcepub fn as_c_slice_range(&self, start: usize, end: usize) -> KeyframesVecSlice
pub fn as_c_slice_range(&self, start: usize, end: usize) -> KeyframesVecSlice
Returns a C-compatible slice of a range within the Vec. If the range is out of bounds, it is clamped to the valid range.
Sourceimpl KeyframesVec
impl KeyframesVec
pub const fn as_mut_ptr(&mut self) -> *mut Keyframes
pub fn sort_by<F: FnMut(&Keyframes, &Keyframes) -> Ordering>( &mut self, compare: F, )
pub fn push(&mut self, value: Keyframes)
pub fn insert(&mut self, index: usize, element: Keyframes)
pub fn remove(&mut self, index: usize)
pub const fn pop(&mut self) -> Option<Keyframes>
pub fn iter_mut(&mut self) -> IterMut<'_, Keyframes> ⓘ
pub fn into_iter(self) -> IntoIter<Keyframes> ⓘ
pub fn append(&mut self, other: &mut Self)
pub fn reserve(&mut self, additional: usize)
pub fn truncate(&mut self, len: usize)
pub fn retain<F>(&mut self, f: F)
Sourceimpl KeyframesVec
impl KeyframesVec
pub fn from_copy_on_write(input: Cow<'static, [Keyframes]>) -> KeyframesVec
Sourcepub unsafe fn copy_from_ptr(ptr: *const Keyframes, len: usize) -> Self
pub unsafe fn copy_from_ptr(ptr: *const Keyframes, len: usize) -> Self
Copies elements from a C array pointer into a new Vec.
Safety
ptrmust be valid for readinglenelements- The memory must be properly aligned for
$struct_type - The elements are cloned, so
$struct_typemust implementClone
Sourcepub fn clone_self(&self) -> Self
pub fn clone_self(&self) -> Self
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated
Sourcepub fn into_library_owned_vec(self) -> Vec<Keyframes>
pub fn into_library_owned_vec(self) -> Vec<Keyframes>
NOTE: CLONES the memory if the memory is external or &’static Moves the memory out if the memory is library-allocated