#[repr(C)]pub struct DesktopEnvVersion {
pub env: LinuxDesktopEnv,
pub version_id: u32,
}Expand description
A desktop environment together with a numeric version (e.g. GNOME 40).
Used by OsVersionCondition::DesktopEnv{Min,Max,Exact} for @os(linux:gnome > 40) style selectors.
Fields
env: LinuxDesktopEnvversion_id: u32Trait Implementations
Sourceimpl Clone for DesktopEnvVersion
impl Clone for DesktopEnvVersion
Sourcefn clone(&self) -> DesktopEnvVersion
fn clone(&self) -> DesktopEnvVersion
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DesktopEnvVersion
impl Debug for DesktopEnvVersion
Sourceimpl Hash for DesktopEnvVersion
impl Hash for DesktopEnvVersion
Sourceimpl PartialEq for DesktopEnvVersion
impl PartialEq for DesktopEnvVersion
Sourcefn eq(&self, other: &DesktopEnvVersion) -> bool
fn eq(&self, other: &DesktopEnvVersion) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for DesktopEnvVersion
impl Eq for DesktopEnvVersion
impl StructuralPartialEq for DesktopEnvVersion