Module angle

Module angle 

CSS property types for angles (degrees, radians, etc.).

Structs

AngleNoValueGivenError
Wrapper for NoValueGiven error in angle parsing.
AngleValue
FloatValue, but associated with a certain metric (i.e. deg, rad, etc.)

Enums

AngleMetric
Enum representing the metric associated with an angle (deg, rad, etc.)
CssAngleValueParseError
Error returned when parsing a CSS angle value from a string.
CssAngleValueParseErrorOwned
Owned version of CssAngleValueParseError for FFI and storage.
OptionAngleValue

Functions

parse_angle_value
Parse a CSS angle value string (e.g. "90deg", "1.57rad", "0.5turn", "50%"). A bare number without a unit suffix is interpreted as degrees.