#[repr(C)]pub struct SvgQuadraticCurve {
pub start: SvgPoint,
pub ctrl: SvgPoint,
pub end: SvgPoint,
}Expand description
A quadratic bezier curve defined by start, one control point, and end point.
Fields
start: SvgPointctrl: SvgPointend: SvgPointImplementations
Sourceimpl SvgQuadraticCurve
impl SvgQuadraticCurve
Sourcepub const fn new(start: SvgPoint, ctrl: SvgPoint, end: SvgPoint) -> Self
pub const fn new(start: SvgPoint, ctrl: SvgPoint, end: SvgPoint) -> Self
Creates a new SvgQuadraticCurve from start, control, and end points
Sourcepub fn get_bounds(&self) -> SvgRect
pub fn get_bounds(&self) -> SvgRect
Returns the axis-aligned bounding box of the curve’s control points.
Sourcepub fn get_x_at_t(&self, t: f64) -> f64
pub fn get_x_at_t(&self, t: f64) -> f64
Evaluates the x coordinate of the curve at parameter t in [0, 1].
Sourcepub fn get_y_at_t(&self, t: f64) -> f64
pub fn get_y_at_t(&self, t: f64) -> f64
Evaluates the y coordinate of the curve at parameter t in [0, 1].
Sourcepub fn get_length(&self) -> f64
pub fn get_length(&self) -> f64
Returns the approximate arc length by converting to a cubic curve.
Sourcepub fn get_t_at_offset(&self, offset: f64) -> f64
pub fn get_t_at_offset(&self, offset: f64) -> f64
Returns the parameter t corresponding to a given arc-length offset.
Sourcepub fn get_tangent_vector_at_t(&self, t: f64) -> SvgVector
pub fn get_tangent_vector_at_t(&self, t: f64) -> SvgVector
Returns the normalized tangent vector at parameter t.