Module direction

Module direction 

CSS property types for direction (for gradients).

Structs

DirectionCorners
A pair of corners representing the start and end of a CSS gradient direction.

Enums

CssDirectionCornerParseError
CssDirectionCornerParseErrorOwned
CssDirectionParseError
CssDirectionParseErrorOwned
Direction
CSS direction (necessary for gradients). Can either be a fixed angle or a direction (“to right” / “to left”, etc.).
DirectionCorner
Corner or side of a rectangle, used to specify CSS gradient directions (e.g. to top right).

Functions

parse_direction