#[repr(C)]pub struct DirectionCorners {
pub dir_from: DirectionCorner,
pub dir_to: DirectionCorner,
}Expand description
A pair of corners representing the start and end of a CSS gradient direction.
Fields
dir_from: DirectionCornerThe corner or side from which the gradient starts.
dir_to: DirectionCornerThe corner or side at which the gradient ends.