#[repr(C)]pub struct ParseFloatErrorWithInput {
pub error: ParseFloatError,
pub input: AzString,
}Expand description
Wrapper for a ParseFloatError paired with the input string that failed. Used by multiple Owned error enums that need to store both the error and input.
Fields
error: ParseFloatErrorinput: AzStringTrait Implementations
Sourceimpl Clone for ParseFloatErrorWithInput
impl Clone for ParseFloatErrorWithInput
Sourcefn clone(&self) -> ParseFloatErrorWithInput
fn clone(&self) -> ParseFloatErrorWithInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ParseFloatErrorWithInput
impl Debug for ParseFloatErrorWithInput
Sourceimpl PartialEq for ParseFloatErrorWithInput
impl PartialEq for ParseFloatErrorWithInput
Sourcefn eq(&self, other: &ParseFloatErrorWithInput) -> bool
fn eq(&self, other: &ParseFloatErrorWithInput) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ParseFloatErrorWithInput