pub fn parse_font_weight(
input: &str,
) -> Result<StyleFontWeight, CssFontWeightParseError<'_>>Expand description
Errors
Returns an error if input is not a valid CSS font-weight value.
pub fn parse_font_weight(
input: &str,
) -> Result<StyleFontWeight, CssFontWeightParseError<'_>>Returns an error if input is not a valid CSS font-weight value.