LayoutRect

Struct LayoutRect 

#[repr(C)]
pub struct LayoutRect { pub origin: LayoutPoint, pub size: LayoutSize, }
Only used for calculations: Rectangle (x, y, width, height) in layout space.

Fields

origin: LayoutPointsize: LayoutSize

Implementations

Source

impl LayoutRect

pub const fn new(origin: LayoutPoint, size: LayoutSize) -> Self

pub const fn zero() -> Self

pub const fn max_x(&self) -> isize

pub const fn min_x(&self) -> isize

pub const fn max_y(&self) -> isize

pub const fn min_y(&self) -> isize

pub const fn width(&self) -> isize

pub const fn height(&self) -> isize

pub const fn contains(&self, other: &LayoutPoint) -> bool

pub fn contains_f32(&self, other_x: f32, other_y: f32) -> bool

pub const fn hit_test(&self, other: &LayoutPoint) -> Option<LayoutPoint>

Like contains(), but returns the (x, y) offset of the hit point relative to the rectangle origin. Unlike contains(), points exactly on the boundary are excluded (returns None).

pub fn union(rects: LayoutRectVecSlice) -> OptionLayoutRect

Returns the bounding rectangle that covers every rectangle in the slice, or OptionLayoutRect::None if the slice is empty.

pub const fn contains_rect(&self, b: &LayoutRect) -> bool

Returns true if b is fully contained inside self.