pub fn parse_image(input: &str) -> Result<AzString, CssImageParseError<'_>>Expand description
A string slice that has been stripped of its quotes.
In CSS, quotes are optional in url() so we accept both quoted and unquoted strings.
Errors
Returns an error if input is not a valid CSS image value.