pub fn parse_layout_max_width(
input: &str,
) -> Result<LayoutMaxWidth, LayoutMaxWidthParseError<'_>>Expand description
Errors
Returns an error if input is not a valid CSS value for this property.
pub fn parse_layout_max_width(
input: &str,
) -> Result<LayoutMaxWidth, LayoutMaxWidthParseError<'_>>Returns an error if input is not a valid CSS value for this property.