pub fn parse_layout_width(
input: &str,
) -> Result<LayoutWidth, LayoutWidthParseError<'_>>Expand description
Errors
Returns an error if input is not a valid CSS value for this property.
pub fn parse_layout_width(
input: &str,
) -> Result<LayoutWidth, LayoutWidthParseError<'_>>Returns an error if input is not a valid CSS value for this property.