pub fn parse_layout_align_self(
input: &str,
) -> Result<LayoutAlignSelf, AlignSelfParseError<'_>>Expand description
Errors
Returns an error if input is not a valid CSS align-self value.
pub fn parse_layout_align_self(
input: &str,
) -> Result<LayoutAlignSelf, AlignSelfParseError<'_>>Returns an error if input is not a valid CSS align-self value.