pub fn parse_layout_flex_grow(
input: &str,
) -> Result<LayoutFlexGrow, FlexGrowParseError<'_>>Expand description
Errors
Returns an error if input is not a valid CSS flex-grow value.
pub fn parse_layout_flex_grow(
input: &str,
) -> Result<LayoutFlexGrow, FlexGrowParseError<'_>>Returns an error if input is not a valid CSS flex-grow value.