Module fragmentation

Module fragmentation 

CSS properties for controlling fragmentation (page/column breaks).

Defines PageBreak, BreakInside, Widows, Orphans, and BoxDecorationBreak. The parser sub-module (behind the parser feature) provides CSS-value parsing for each type.

Re-exports

pub use parser::*;

Modules

parser

Structs

Orphans
CSS orphans property - minimum number of lines in a block container that must be shown at the bottom of a page, region, or column.
Widows
CSS widows property - minimum number of lines in a block container that must be shown at the top of a page, region, or column.

Enums

BoxDecorationBreak
Represents a box-decoration-break CSS property value.
BreakInside
Represents a break-inside CSS property value.
PageBreak
Represents a break-before or break-after CSS property value.