pub fn parse_layout_justify_items(
input: &str,
) -> Result<LayoutJustifyItems, JustifyItemsParseError<'_>>Expand description
Errors
Returns an error if input is not a valid CSS justify-items value.
pub fn parse_layout_justify_items(
input: &str,
) -> Result<LayoutJustifyItems, JustifyItemsParseError<'_>>Returns an error if input is not a valid CSS justify-items value.