pub fn parse_layout_justify_self(
input: &str,
) -> Result<LayoutJustifySelf, JustifySelfParseError<'_>>Expand description
Errors
Returns an error if input is not a valid CSS justify-self value.
pub fn parse_layout_justify_self(
input: &str,
) -> Result<LayoutJustifySelf, JustifySelfParseError<'_>>Returns an error if input is not a valid CSS justify-self value.