#[repr(C)]pub enum StyleTextOverflow {
Clip = 0,
Ellipsis = 1,
}Expand description
Represents the text-overflow CSS property.
Determines how inline content that is clipped (because the block container
has overflow other than visible) is signaled to the user at the end of
the line box.
CSS Overflow Module Level 3 5: https://www.w3.org/TR/css-overflow-3/#text-overflow
Variants
Clip = 0
Clip the inline content at the edge of its line box. This is the initial value.
Ellipsis = 1
Render an ellipsis (…, U+2026) to represent clipped inline content.