pub fn parse_layout_right(
input: &str,
) -> Result<LayoutRight, LayoutRightParseError<'_>>Expand description
Errors
Returns an error if input is not a valid CSS value for this property.
pub fn parse_layout_right(
input: &str,
) -> Result<LayoutRight, LayoutRightParseError<'_>>Returns an error if input is not a valid CSS value for this property.