pub fn parse_shape_inside(input: &str) -> Result<ShapeInside, ShapeParseError>Expand description
Parser for shape-inside property
Errors
Returns an error if input is not a valid CSS shape-inside value.
pub fn parse_shape_inside(input: &str) -> Result<ShapeInside, ShapeParseError>Parser for shape-inside property
Returns an error if input is not a valid CSS shape-inside value.