pub fn parse_shape_margin(
input: &str,
) -> Result<ShapeMargin, CssPixelValueParseError<'_>>Expand description
Parser for shape-margin property
Errors
Returns an error if input is not a valid CSS shape-margin value.
pub fn parse_shape_margin(
input: &str,
) -> Result<ShapeMargin, CssPixelValueParseError<'_>>Parser for shape-margin property
Returns an error if input is not a valid CSS shape-margin value.