pub fn parse_shape_outside(input: &str) -> Result<ShapeOutside, ShapeParseError>Expand description
Parser for shape-outside property
Errors
Returns an error if input is not a valid CSS shape-outside value.
pub fn parse_shape_outside(input: &str) -> Result<ShapeOutside, ShapeParseError>Parser for shape-outside property
Returns an error if input is not a valid CSS shape-outside value.