Module table

Module table 

CSS properties for table layout and styling.

This module contains properties specific to CSS table formatting:

  • table-layout: Controls the algorithm used to layout table cells, rows, and columns
  • border-collapse: Specifies whether cell borders are collapsed into a single border or separated
  • border-spacing: Sets the distance between borders of adjacent cells (separate borders only)
  • caption-side: Specifies the placement of a table caption
  • empty-cells: Specifies whether or not to display borders on empty cells in a table

Structs

LayoutBorderSpacing
Sets the distance between the borders of adjacent cells.

Enums

LayoutTableLayout
Controls the algorithm used to lay out table cells, rows, and columns.
StyleBorderCollapse
Specifies whether cell borders are collapsed into a single border or separated.
StyleCaptionSide
Specifies the placement of a table caption.
StyleEmptyCells
Specifies whether or not to display borders and background on empty cells.