pub fn parse_layout_clear(
input: &str,
) -> Result<LayoutClear, LayoutClearParseError<'_>>Expand description
Errors
Returns an error if input is not a valid CSS clear value.
pub fn parse_layout_clear(
input: &str,
) -> Result<LayoutClear, LayoutClearParseError<'_>>Returns an error if input is not a valid CSS clear value.