Module property

Module property 

Defines the core CssProperty enum, which represents any single parsed CSS property, as well as top-level functions for parsing CSS keys and values.

Structs

CssKeyMap
CssPropertyVec
CssPropertyVecSlice
C-compatible slice type for $struct_name. This is a non-owning view into a Vec’s data.

Enums

CombinedCssPropertyType
CssParsingError
Master error type that aggregates all possible CSS parsing errors.
CssParsingErrorOwned
Owned version of CssParsingError.
CssProperty
Represents one parsed CSS key-value pair, such as "width: 20px" => CssProperty::Width(LayoutWidth::px(20.0))
CssPropertyCategory
Categorizes a CSS property by its effect on the layout pipeline.
CssPropertyType
Represents a CSS key (for example "border-radius" => BorderRadius). You can also derive this key from a CssProperty by calling CssProperty::get_type().
CssPropertyVecDestructor
OptionCssProperty
RelayoutScope
Fine-grained dirty classification for CSS property changes.

Functions

format_static_css_prop
get_css_key_map
Returns a map useful for parsing the keys of CSS stylesheets
parse_combined_css_property
Parses a combined CSS property or a CSS property shorthand, for example “margin” (as a shorthand for setting all four properties of “margin-top”, “margin-bottom”, “margin-left” and “margin-right”)
parse_css_property
Errors

Type Aliases

BoxDecorationBreakValue
BreakInsideValue
CaretAnimationDurationValue
CaretColorValue
CaretWidthValue
ClipPathValue
ColumnCountValue
ColumnFillValue
ColumnRuleColorValue
ColumnRuleStyleValue
ColumnRuleWidthValue
ColumnSpanValue
ColumnWidthValue
ContentValue
CounterIncrementValue
CounterResetValue
CssPropertyVecDestructorType
FlowFromValue
FlowIntoValue
LayoutAlignContentValue
LayoutAlignItemsValue
LayoutAlignSelfValue
LayoutBorderBottomWidthValue
LayoutBorderLeftWidthValue
LayoutBorderRightWidthValue
LayoutBorderSpacingValue
LayoutBorderTopWidthValue
LayoutBoxSizingValue
LayoutClearValue
LayoutColumnGapValue
LayoutDisplayValue
LayoutFlexBasisValue
LayoutFlexDirectionValue
LayoutFlexGrowValue
LayoutFlexShrinkValue
LayoutFlexWrapValue
LayoutFloatValue
LayoutGapValue
LayoutGridAutoColumnsValue
LayoutGridAutoFlowValue
LayoutGridAutoRowsValue
LayoutGridColumnValue
LayoutGridRowValue
LayoutGridTemplateAreasValue
LayoutGridTemplateColumnsValue
LayoutGridTemplateRowsValue
LayoutHeightValue
LayoutInsetBottomValue
LayoutJustifyContentValue
LayoutJustifyItemsValue
LayoutJustifySelfValue
LayoutLeftValue
LayoutMarginBottomValue
LayoutMarginLeftValue
LayoutMarginRightValue
LayoutMarginTopValue
LayoutMaxHeightValue
LayoutMaxWidthValue
LayoutMinHeightValue
LayoutMinWidthValue
LayoutOverflowValue
LayoutPaddingBottomValue
LayoutPaddingInlineEndValue
LayoutPaddingInlineStartValue
LayoutPaddingLeftValue
LayoutPaddingRightValue
LayoutPaddingTopValue
LayoutPositionValue
LayoutRightValue
LayoutRowGapValue
LayoutScrollbarWidthValue
LayoutTableLayoutValue
LayoutTextJustifyValue
LayoutTopValue
LayoutWidthValue
LayoutWritingModeValue
LayoutZIndexValue
OrphansValue
PageBreakValue
ScrollbarFadeDelayValue
ScrollbarFadeDurationValue
ScrollbarVisibilityModeValue
SelectionBackgroundColorValue
SelectionColorValue
SelectionRadiusValue
ShapeImageThresholdValue
ShapeInsideValue
ShapeMarginValue
ShapeOutsideValue
StringSetValue
StyleAlignmentBaselineValue
StyleAspectRatioValue
StyleBackfaceVisibilityValue
StyleBackgroundContentValue
StyleBackgroundContentVecValue
StyleBackgroundPositionVecValue
StyleBackgroundRepeatVecValue
StyleBackgroundSizeVecValue
StyleBaselineSourceValue
StyleBorderBottomColorValue
StyleBorderBottomLeftRadiusValue
StyleBorderBottomRightRadiusValue
StyleBorderBottomStyleValue
StyleBorderCollapseValue
StyleBorderLeftColorValue
StyleBorderLeftStyleValue
StyleBorderRightColorValue
StyleBorderRightStyleValue
StyleBorderTopColorValue
StyleBorderTopLeftRadiusValue
StyleBorderTopRightRadiusValue
StyleBorderTopStyleValue
StyleBoxShadowValue
StyleCaptionSideValue
StyleClipRectValue
StyleCursorValue
StyleDirectionValue
StyleDominantBaselineValue
StyleEmptyCellsValue
StyleExclusionMarginValue
StyleFilterVecValue
StyleFontFamilyVecValue
StyleFontSizeValue
StyleFontStyleValue
StyleFontValue
StyleFontWeightValue
StyleHangingPunctuationValue
StyleHyphenationLanguageValue
StyleHyphensValue
StyleInitialLetterAlignValue
StyleInitialLetterValue
StyleInitialLetterWrapValue
StyleLetterSpacingValue
StyleLineBreakValue
StyleLineClampValue
StyleLineFitEdgeValue
StyleLineHeightValue
StyleListStylePositionValue
StyleListStyleTypeValue
StyleMixBlendModeValue
StyleObjectFitValue
StyleObjectPositionValue
StyleOpacityValue
StyleOverflowClipMarginValue
StyleOverflowWrapValue
StylePerspectiveOriginValue
StyleScrollbarColorValue
StyleScrollbarGutterValue
StyleTabSizeValue
StyleTextAlignLastValue
StyleTextAlignValue
StyleTextBoxEdgeValue
StyleTextBoxTrimValue
StyleTextColorValue
StyleTextCombineUprightValue
StyleTextDecorationValue
StyleTextIndentValue
StyleTextOrientationValue
StyleTextOverflowValue
StyleTextTransformValue
StyleTransformOriginValue
StyleTransformVecValue
StyleUnicodeBidiValue
StyleUserSelectValue
StyleVerticalAlignValue
StyleVisibilityValue
StyleWhiteSpaceValue
StyleWordBreakValue
StyleWordSpacingValue
WidowsValue