CombinedCssPropertyType

Enum CombinedCssPropertyType 

#[repr(C)]
pub enum CombinedCssPropertyType {
Show 27 variants BorderRadius = 0, Overflow = 1, Margin = 2, Border = 3, BorderLeft = 4, BorderRight = 5, BorderTop = 6, BorderBottom = 7, BorderColor = 8, BorderStyle = 9, BorderWidth = 10, Padding = 11, BoxShadow = 12, BackgroundColor = 13, BackgroundImage = 14, Background = 15, Flex = 16, Grid = 17, Gap = 18, GridGap = 19, Font = 20, Columns = 21, ColumnRule = 22, GridArea = 23, TextBox = 24, InsetBlock = 25, InsetInline = 26,
}

Variants



BorderRadius = 0



Overflow = 1



Margin = 2



Border = 3



BorderLeft = 4



BorderRight = 5



BorderTop = 6



BorderBottom = 7



BorderColor = 8



BorderStyle = 9



BorderWidth = 10



Padding = 11



BoxShadow = 12



BackgroundColor = 13



BackgroundImage = 14



Background = 15



Flex = 16



Grid = 17



Gap = 18



GridGap = 19



Font = 20



Columns = 21



ColumnRule = 22



GridArea = 23



TextBox = 24



InsetBlock = 25

inset-block shorthand: sets inset-block-start + inset-block-end (maps to top + bottom in horizontal-tb writing mode)



InsetInline = 26

inset-inline shorthand: sets inset-inline-start + inset-inline-end (maps to left + right in horizontal-tb writing mode)

Implementations

Source

impl CombinedCssPropertyType

pub fn from_str(input: &str, map: &CssKeyMap) -> Option<Self>

Parses a CSS key, such as width from a string:

Example
let map = get_css_key_map();
assert_eq!(
    Some(CombinedCssPropertyType::Border),
    CombinedCssPropertyType::from_str("border", &map)
);
pub fn to_str(&self, map: &CssKeyMap) -> &'static str

Returns the original string that was used to construct this CssPropertyType.

Panics

Panics if self is not present in map (i.e. map is not the CssKeyMap this property type was constructed from).