CssPropertyType

Enum CssPropertyType 

#[repr(C)]
pub enum CssPropertyType {
Show 191 variants CaretColor = 0, CaretAnimationDuration = 1, Animation = 2, AnimationIn = 3, AnimationOut = 4, CaretWidth = 5, SelectionBackgroundColor = 6, SelectionColor = 7, SelectionRadius = 8, TextColor = 9, FontSize = 10, FontFamily = 11, FontWeight = 12, FontStyle = 13, TextAlign = 14, TextJustify = 15, VerticalAlign = 16, LetterSpacing = 17, TextIndent = 18, InitialLetter = 19, LineClamp = 20, HangingPunctuation = 21, TextCombineUpright = 22, UnicodeBidi = 23, TextBoxTrim = 24, TextBoxEdge = 25, DominantBaseline = 26, AlignmentBaseline = 27, BaselineSource = 28, LineFitEdge = 29, InitialLetterAlign = 30, InitialLetterWrap = 31, ScrollbarGutter = 32, OverflowClipMargin = 33, Clip = 34, ExclusionMargin = 35, HyphenationLanguage = 36, LineHeight = 37, WordSpacing = 38, TabSize = 39, WhiteSpace = 40, Hyphens = 41, WordBreak = 42, OverflowWrap = 43, LineBreak = 44, TextOverflow = 45, ObjectFit = 46, ObjectPosition = 47, AspectRatio = 48, TextOrientation = 49, TextAlignLast = 50, TextTransform = 51, Direction = 52, UserSelect = 53, TextDecoration = 54, Cursor = 55, Display = 56, Float = 57, BoxSizing = 58, Width = 59, Height = 60, MinWidth = 61, MinHeight = 62, MaxWidth = 63, MaxHeight = 64, Position = 65, Top = 66, Right = 67, Left = 68, Bottom = 69, ZIndex = 70, FlexWrap = 71, FlexDirection = 72, FlexGrow = 73, FlexShrink = 74, FlexBasis = 75, JustifyContent = 76, AlignItems = 77, AlignContent = 78, ColumnGap = 79, RowGap = 80, GridTemplateColumns = 81, GridTemplateRows = 82, GridAutoColumns = 83, GridAutoRows = 84, GridColumn = 85, GridRow = 86, GridTemplateAreas = 87, GridAutoFlow = 88, JustifySelf = 89, JustifyItems = 90, Gap = 91, GridGap = 92, AlignSelf = 93, Font = 94, WritingMode = 95, Clear = 96, BackgroundContent = 97, BackgroundPosition = 98, BackgroundSize = 99, BackgroundRepeat = 100, OverflowX = 101, OverflowY = 102, OverflowBlock = 103, OverflowInline = 104, PaddingTop = 105, PaddingLeft = 106, PaddingRight = 107, PaddingBottom = 108, PaddingInlineStart = 109, PaddingInlineEnd = 110, MarginTop = 111, MarginLeft = 112, MarginRight = 113, MarginBottom = 114, BorderTopLeftRadius = 115, BorderTopRightRadius = 116, BorderBottomLeftRadius = 117, BorderBottomRightRadius = 118, BorderTopColor = 119, BorderRightColor = 120, BorderLeftColor = 121, BorderBottomColor = 122, BorderTopStyle = 123, BorderRightStyle = 124, BorderLeftStyle = 125, BorderBottomStyle = 126, BorderTopWidth = 127, BorderRightWidth = 128, BorderLeftWidth = 129, BorderBottomWidth = 130, BoxShadowLeft = 131, BoxShadowRight = 132, BoxShadowTop = 133, BoxShadowBottom = 134, ScrollbarTrack = 135, ScrollbarThumb = 136, ScrollbarButton = 137, ScrollbarCorner = 138, ScrollbarResizer = 139, ScrollbarWidth = 140, OverscrollBehaviorX = 141, OverscrollBehaviorY = 142, ScrollbarColor = 143, ScrollbarVisibility = 144, ScrollbarFadeDelay = 145, ScrollbarFadeDuration = 146, Opacity = 147, Visibility = 148, Transform = 149, TransformOrigin = 150, PerspectiveOrigin = 151, BackfaceVisibility = 152, AppRegion = 153, SpatialNavigationAction = 154, SpatialNavigationContain = 155, MixBlendMode = 156, Filter = 157, BackdropFilter = 158, TextShadow = 159, BreakBefore = 160, BreakAfter = 161, BreakInside = 162, Orphans = 163, Widows = 164, BoxDecorationBreak = 165, ColumnCount = 166, ColumnWidth = 167, ColumnSpan = 168, ColumnFill = 169, ColumnRuleWidth = 170, ColumnRuleStyle = 171, ColumnRuleColor = 172, FlowInto = 173, FlowFrom = 174, ShapeOutside = 175, ShapeInside = 176, ClipPath = 177, ShapeMargin = 178, ShapeImageThreshold = 179, TableLayout = 180, BorderCollapse = 181, BorderSpacing = 182, CaptionSide = 183, EmptyCells = 184, Content = 185, CounterReset = 186, CounterIncrement = 187, ListStyleType = 188, ListStylePosition = 189, StringSet = 190,
}
Represents a CSS key (for example "border-radius" => BorderRadius). You can also derive this key from a CssProperty by calling CssProperty::get_type().

Variants



CaretColor = 0



CaretAnimationDuration = 1



Animation = 2



AnimationIn = 3



AnimationOut = 4



CaretWidth = 5



SelectionBackgroundColor = 6



SelectionColor = 7



SelectionRadius = 8



TextColor = 9



FontSize = 10



FontFamily = 11



FontWeight = 12



FontStyle = 13



TextAlign = 14



TextJustify = 15



VerticalAlign = 16



LetterSpacing = 17



TextIndent = 18



InitialLetter = 19



LineClamp = 20



HangingPunctuation = 21



TextCombineUpright = 22



UnicodeBidi = 23



TextBoxTrim = 24



TextBoxEdge = 25



DominantBaseline = 26



AlignmentBaseline = 27



BaselineSource = 28



LineFitEdge = 29



InitialLetterAlign = 30



InitialLetterWrap = 31



ScrollbarGutter = 32



OverflowClipMargin = 33



Clip = 34



ExclusionMargin = 35



HyphenationLanguage = 36



LineHeight = 37



WordSpacing = 38



TabSize = 39



WhiteSpace = 40



Hyphens = 41



WordBreak = 42



OverflowWrap = 43



LineBreak = 44



TextOverflow = 45



ObjectFit = 46



ObjectPosition = 47



AspectRatio = 48



TextOrientation = 49



TextAlignLast = 50



TextTransform = 51



Direction = 52



UserSelect = 53



TextDecoration = 54



Cursor = 55



Display = 56



Float = 57



BoxSizing = 58



Width = 59



Height = 60



MinWidth = 61



MinHeight = 62



MaxWidth = 63



MaxHeight = 64



Position = 65



Top = 66



Right = 67



Left = 68



Bottom = 69



ZIndex = 70



FlexWrap = 71



FlexDirection = 72



FlexGrow = 73



FlexShrink = 74



FlexBasis = 75



JustifyContent = 76



AlignItems = 77



AlignContent = 78



ColumnGap = 79



RowGap = 80



GridTemplateColumns = 81



GridTemplateRows = 82



GridAutoColumns = 83



GridAutoRows = 84



GridColumn = 85



GridRow = 86



GridTemplateAreas = 87



GridAutoFlow = 88



JustifySelf = 89



JustifyItems = 90



Gap = 91



GridGap = 92



AlignSelf = 93



Font = 94



WritingMode = 95



Clear = 96



BackgroundContent = 97



BackgroundPosition = 98



BackgroundSize = 99



BackgroundRepeat = 100



OverflowX = 101



OverflowY = 102



OverflowBlock = 103



OverflowInline = 104



PaddingTop = 105



PaddingLeft = 106



PaddingRight = 107



PaddingBottom = 108



PaddingInlineStart = 109



PaddingInlineEnd = 110



MarginTop = 111



MarginLeft = 112



MarginRight = 113



MarginBottom = 114



BorderTopLeftRadius = 115



BorderTopRightRadius = 116



BorderBottomLeftRadius = 117



BorderBottomRightRadius = 118



BorderTopColor = 119



BorderRightColor = 120



BorderLeftColor = 121



BorderBottomColor = 122



BorderTopStyle = 123



BorderRightStyle = 124



BorderLeftStyle = 125



BorderBottomStyle = 126



BorderTopWidth = 127



BorderRightWidth = 128



BorderLeftWidth = 129



BorderBottomWidth = 130



BoxShadowLeft = 131



BoxShadowRight = 132



BoxShadowTop = 133



BoxShadowBottom = 134



ScrollbarTrack = 135



ScrollbarThumb = 136



ScrollbarButton = 137



ScrollbarCorner = 138



ScrollbarResizer = 139



ScrollbarWidth = 140



OverscrollBehaviorX = 141



OverscrollBehaviorY = 142



ScrollbarColor = 143



ScrollbarVisibility = 144



ScrollbarFadeDelay = 145



ScrollbarFadeDuration = 146



Opacity = 147



Visibility = 148



Transform = 149



TransformOrigin = 150



PerspectiveOrigin = 151



BackfaceVisibility = 152



AppRegion = 153



SpatialNavigationAction = 154



SpatialNavigationContain = 155



MixBlendMode = 156



Filter = 157



BackdropFilter = 158



TextShadow = 159



BreakBefore = 160



BreakAfter = 161



BreakInside = 162



Orphans = 163



Widows = 164



BoxDecorationBreak = 165



ColumnCount = 166



ColumnWidth = 167



ColumnSpan = 168



ColumnFill = 169



ColumnRuleWidth = 170



ColumnRuleStyle = 171



ColumnRuleColor = 172



FlowInto = 173



FlowFrom = 174



ShapeOutside = 175



ShapeInside = 176



ClipPath = 177



ShapeMargin = 178



ShapeImageThreshold = 179



TableLayout = 180



BorderCollapse = 181



BorderSpacing = 182



CaptionSide = 183



EmptyCells = 184



Content = 185



CounterReset = 186



CounterIncrement = 187



ListStyleType = 188



ListStylePosition = 189



StringSet = 190

Implementations

Source

impl CssPropertyType

pub const ALL: &[Self]

All CSS property types, in declaration order.

Use this instead of strum’s EnumIter — ensures a compile error if a variant is added to the enum but not to this array.

pub fn iter() -> impl Iterator<Item = Self>

Returns an iterator over all CSS property types.

Source

impl CssPropertyType

pub fn from_str(input: &str, map: &CssKeyMap) -> Option<Self>

Parses a CSS key, such as width from a string:

Example
let map = get_css_key_map();
assert_eq!(
    Some(CssPropertyType::Width),
    CssPropertyType::from_str("width", &map)
);
assert_eq!(
    Some(CssPropertyType::JustifyContent),
    CssPropertyType::from_str("justify-content", &map)
);
assert_eq!(None, CssPropertyType::from_str("asdfasdfasdf", &map));
pub const fn to_str(&self) -> &'static str

Returns the original string that was used to construct this CssPropertyType.

pub const fn is_inheritable(&self) -> bool

Returns whether this property will be inherited during cascading Returns whether this CSS property is inherited by default according to CSS specifications.

Reference: https://developer.mozilla.org/en-US/docs/Web/CSS/Guides/Cascade/Inheritance

pub const fn has_compact_encoding(&self) -> bool

pub const fn get_category(&self) -> CssPropertyCategory

pub const fn can_trigger_relayout(&self) -> bool

Returns whether this property can trigger a re-layout (important for incremental layout and caching layouted DOMs).

pub const fn is_gpu_only_property(&self) -> bool

Returns whether the property is a GPU property (currently only opacity and transforms)

pub const fn relayout_scope(&self, node_is_ifc_member: bool) -> RelayoutScope

Context-dependent relayout scope for a CSS property change.

This is a more granular replacement for can_trigger_relayout(). Instead of returning a flat bool, it classifies the property change into one of four impact levels (see RelayoutScope).

Inspired by Taffy’s binary dirty flag, extended with CSS-specific knowledge: font/text changes only affect IFC, sizing changes don’t require full subtree relayout, and paint-only changes skip layout entirely.

node_is_ifc_member: whether this node participates in an IFC (has inline formatting context membership). When true, font/text property changes trigger IFC-only relayout instead of being ignored.