pub fn parse_css_property(
key: CssPropertyType,
value: &str,
) -> Result<CssProperty, CssParsingError<'_>>Expand description
Errors
Returns an error if input is not a valid CSS css-property value.
pub fn parse_css_property(
key: CssPropertyType,
value: &str,
) -> Result<CssProperty, CssParsingError<'_>>Returns an error if input is not a valid CSS css-property value.