parse_style_background_content

Function parse_style_background_content 

pub fn parse_style_background_content(
    input: &str,
) -> Result<StyleBackgroundContent, CssBackgroundParseError<'_>>
Parses a single background value, which can be a color, image, or gradient.

Errors

Returns an error if input is not a valid CSS background-content value.