pub fn parse_border_left_width(
input: &str,
) -> Result<LayoutBorderLeftWidth, CssPixelValueParseError<'_>>Expand description
Errors
Returns an error if input is not a valid CSS border-left-width value.
pub fn parse_border_left_width(
input: &str,
) -> Result<LayoutBorderLeftWidth, CssPixelValueParseError<'_>>Returns an error if input is not a valid CSS border-left-width value.