pub fn parse_border_right_width(
input: &str,
) -> Result<LayoutBorderRightWidth, CssPixelValueParseError<'_>>Expand description
Errors
Returns an error if input is not a valid CSS border-right-width value.
pub fn parse_border_right_width(
input: &str,
) -> Result<LayoutBorderRightWidth, CssPixelValueParseError<'_>>Returns an error if input is not a valid CSS border-right-width value.