pub fn parse_style_border(
input: &str,
) -> Result<StyleBorderSide, CssBorderParseError<'_>>Expand description
Errors
Returns an error if input is not a valid CSS border value.
pub fn parse_style_border(
input: &str,
) -> Result<StyleBorderSide, CssBorderParseError<'_>>Returns an error if input is not a valid CSS border value.