Module scrollbar

Module scrollbar 

CSS properties for styling scrollbars.

Structs

ComputedScrollbarStyle
The final, resolved style for a scrollbar, after considering both standard and -webkit- properties. This struct is intended for use by the layout engine.
ScrollPhysics
Scroll physics configuration for momentum scrolling
ScrollbarColorCustom
Wrapper struct for custom scrollbar colors (thumb and track)
ScrollbarFadeDelay
Time in milliseconds before the overlay scrollbar starts fading out.
ScrollbarFadeDuration
Duration in milliseconds of the scrollbar fade-out animation.
ScrollbarInfo
Holds info necessary for layouting / styling -webkit-scrollbar properties.
ScrollbarStyle
Scrollbar style for both horizontal and vertical scrollbars.

Enums

LayoutScrollbarWidth
Represents the standard scrollbar-width property.
LayoutScrollbarWidthParseError
LayoutScrollbarWidthParseErrorOwned
OverflowScrolling
Controls per-node rubber-banding / momentum scrolling behavior.
OverscrollBehavior
CSS overscroll-behavior property - controls overscroll effects https://developer.mozilla.org/en-US/docs/Web/CSS/overscroll-behavior
ScrollBehavior
CSS scroll-behavior property - controls smooth scrolling https://developer.mozilla.org/en-US/docs/Web/CSS/scroll-behavior
ScrollbarFadeDelayParseError
ScrollbarFadeDelayParseErrorOwned
ScrollbarFadeDurationParseError
ScrollbarFadeDurationParseErrorOwned
ScrollbarVisibilityMode
Controls when the scrollbar is displayed.
ScrollbarVisibilityModeParseError
ScrollbarVisibilityModeParseErrorOwned
StyleScrollbarColor
Represents the standard scrollbar-color property.
StyleScrollbarColorParseError
StyleScrollbarColorParseErrorOwned

Constants

SCROLLBAR_ANDROID_DARK
A modern, thin, overlay scrollbar inspired by Android (Dark Theme).
SCROLLBAR_ANDROID_LIGHT
A modern, thin, overlay scrollbar inspired by Android (Light Theme).
SCROLLBAR_CLASSIC_DARK
A classic dark-themed scrollbar.
SCROLLBAR_CLASSIC_LIGHT
A classic light-themed scrollbar, similar to older Windows versions.
SCROLLBAR_IOS_DARK
A modern, thin, overlay scrollbar inspired by iOS (Dark Theme).
SCROLLBAR_IOS_LIGHT
A modern, thin, overlay scrollbar inspired by iOS (Light Theme).
SCROLLBAR_MACOS_DARK
A modern, thin, overlay scrollbar inspired by macOS (Dark Theme).
SCROLLBAR_MACOS_LIGHT
A modern, thin, overlay scrollbar inspired by macOS (Light Theme).
SCROLLBAR_WINDOWS_DARK
A modern scrollbar inspired by Windows 11 (Dark Theme).
SCROLLBAR_WINDOWS_LIGHT
A modern scrollbar inspired by Windows 11 (Light Theme).

Functions

parse_layout_scrollbar_width
Errors
parse_scrollbar_fade_delay
Errors
parse_scrollbar_fade_duration
Errors
parse_scrollbar_visibility_mode
Errors
parse_style_scrollbar_color
Errors