pub fn parse_layout_scrollbar_width(
input: &str,
) -> Result<LayoutScrollbarWidth, LayoutScrollbarWidthParseError<'_>>Expand description
Errors
Returns an error if input is not a valid CSS scrollbar-width value.
pub fn parse_layout_scrollbar_width(
input: &str,
) -> Result<LayoutScrollbarWidth, LayoutScrollbarWidthParseError<'_>>Returns an error if input is not a valid CSS scrollbar-width value.