#[repr(C)]pub enum StyleLineBreak {
Auto = 0,
Loose = 1,
Normal = 2,
Strict = 3,
Anywhere = 4,
}Expand description
Controls the strictness of line breaking rules.
CSS Text Level 3: https://www.w3.org/TR/css-text-3/#line-break-property
Variants
Auto = 0
The browser determines the set of line-breaking restrictions to use.
Loose = 1
Breaks text using the least restrictive set of line-breaking rules.
Normal = 2
Breaks text using the most common set of line-breaking rules.
Strict = 3
Breaks text using the most stringent set of line-breaking rules.
Anywhere = 4
There is a soft wrap opportunity around every typographic character unit, including around any punctuation character or preserved white spaces, or in the middle of words, disregarding any prohibition against line breaks.