#[repr(C)]pub enum StyleOverflowWrap {
Normal = 0,
Anywhere = 1,
BreakWord = 2,
}Expand description
Controls whether the browser may break at otherwise disallowed points to prevent overflow.
CSS Text Level 3 3.3: https://www.w3.org/TR/css-text-3/#overflow-wrap-property
Variants
Normal = 0
Lines may only break at allowed break points.
Anywhere = 1
An otherwise unbreakable sequence may be broken at an arbitrary point if there are no otherwise acceptable break points.
BreakWord = 2
Same as anywhere but soft wrap opportunities introduced are not
considered when calculating min-content intrinsic sizes.