#[repr(C)]pub enum StyleTextAlignLast {
Auto = 0,
Start = 1,
End = 2,
Left = 3,
Right = 4,
Center = 5,
Justify = 6,
}Expand description
Controls alignment of the last line of a block or a line right before a forced line break.
CSS Text Level 3 7.2: https://www.w3.org/TR/css-text-3/#text-align-last-property
Variants
Auto = 0
Alignment of the last line is determined by text-align (or start if justify).
Start = 1
Align to the start edge of the line box.
End = 2
Align to the end edge of the line box.
Left = 3
Align to the line left.
Right = 4
Align to the line right.
Center = 5
Center the content.
Justify = 6
Justify the content.