#[repr(C, u8)]pub enum StyleVerticalAlign {
Baseline,
Top,
Middle,
Bottom,
Sub,
Superscript,
TextTop,
TextBottom,
Percentage(PercentageValue),
Length(PixelValue),
}Expand description
CSS 2.2 10.8.1 vertical-align property values
Variants
Baseline
CSS default - align baselines
Top
Align top of element with top of line box
Middle
Align middle of element with baseline + half x-height
Bottom
Align bottom of element with bottom of line box
Sub
Align baseline with parent’s subscript baseline
Superscript
Align baseline with parent’s superscript baseline
TextTop
Align top with top of parent’s font
TextBottom
Align bottom with bottom of parent’s font
Percentage(PercentageValue)
Length(PixelValue)