#[repr(C)]pub struct ShapeEllipse {
pub center: ShapePoint,
pub radius_x: f32,
pub radius_y: f32,
}Expand description
An ellipse shape defined by center point and two radii
Fields
center: ShapePointradius_x: f32radius_y: f32Trait Implementations
Sourceimpl Clone for ShapeEllipse
impl Clone for ShapeEllipse
Sourcefn clone(&self) -> ShapeEllipse
fn clone(&self) -> ShapeEllipse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ShapeEllipse
impl Debug for ShapeEllipse
Sourceimpl Hash for ShapeEllipse
impl Hash for ShapeEllipse
Sourceimpl Ord for ShapeEllipse
impl Ord for ShapeEllipse
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ShapeEllipse
impl PartialEq for ShapeEllipse
Sourcefn eq(&self, other: &ShapeEllipse) -> bool
fn eq(&self, other: &ShapeEllipse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ShapeEllipse
impl PartialOrd for ShapeEllipse
impl Eq for ShapeEllipse
impl StructuralPartialEq for ShapeEllipse