CSS property types for angles (degrees, radians, etc.).
Structs
- Angle
NoValue Given Error - Wrapper for NoValueGiven error in angle parsing.
- Angle
Value - FloatValue, but associated with a certain metric (i.e. deg, rad, etc.)
Enums
- Angle
Metric - Enum representing the metric associated with an angle (deg, rad, etc.)
- CssAngle
Value Parse Error - Error returned when parsing a CSS angle value from a string.
- CssAngle
Value Parse Error Owned - Owned version of
CssAngleValueParseErrorfor FFI and storage. - Option
Angle Value
Functions
- parse_
angle_ value - Parse a CSS angle value string (e.g.
"90deg","1.57rad","0.5turn","50%"). A bare number without a unit suffix is interpreted as degrees.