CSS property types for direction (for gradients).
Structs
- Direction
Corners - A pair of corners representing the start and end of a CSS gradient direction.
Enums
- CssDirection
Corner Parse Error - CssDirection
Corner Parse Error Owned - CssDirection
Parse Error - CssDirection
Parse Error Owned - Direction
- CSS direction (necessary for gradients). Can either be a fixed angle or a direction (“to right” / “to left”, etc.).
- Direction
Corner - Corner or side of a rectangle, used to specify CSS gradient directions
(e.g.
to top right).