pub fn parse_pixel_value_with_auto(
input: &str,
) -> Result<PixelValueWithAuto, CssPixelValueParseError<'_>>Expand description
Parses a pixel value, but also tries values like “auto”, “initial”, “inherit” and “none”
Errors
Returns an error if input is not a valid CSS pixel-value-with-auto value.