CSS properties for controlling fragmentation (page/column breaks).
Defines PageBreak, BreakInside, Widows, Orphans, and
BoxDecorationBreak. The parser sub-module (behind the parser
feature) provides CSS-value parsing for each type.
Re-exports
pub use parser::*;
Modules
Structs
- Orphans
- CSS
orphansproperty - minimum number of lines in a block container that must be shown at the bottom of a page, region, or column. - Widows
- CSS
widowsproperty - minimum number of lines in a block container that must be shown at the top of a page, region, or column.
Enums
- BoxDecoration
Break - Represents a
box-decoration-breakCSS property value. - Break
Inside - Represents a
break-insideCSS property value. - Page
Break - Represents a
break-beforeorbreak-afterCSS property value.