CSS properties for table layout and styling.
This module contains properties specific to CSS table formatting:
table-layout: Controls the algorithm used to layout table cells, rows, and columnsborder-collapse: Specifies whether cell borders are collapsed into a single border or separatedborder-spacing: Sets the distance between borders of adjacent cells (separate borders only)caption-side: Specifies the placement of a table captionempty-cells: Specifies whether or not to display borders on empty cells in a table
Structs
- Layout
Border Spacing - Sets the distance between the borders of adjacent cells.
Enums
- Layout
Table Layout - Controls the algorithm used to lay out table cells, rows, and columns.
- Style
Border Collapse - Specifies whether cell borders are collapsed into a single border or separated.
- Style
Caption Side - Specifies the placement of a table caption.
- Style
Empty Cells - Specifies whether or not to display borders and background on empty cells.