pub fn parse_style_background_content<'a>(
input: &'a str,
) -> Result<StyleBackgroundContent, CssBackgroundParseError<'a>>Expand description
Parses a single background value, which can be a color, image, or gradient.
pub fn parse_style_background_content<'a>(
input: &'a str,
) -> Result<StyleBackgroundContent, CssBackgroundParseError<'a>>Parses a single background value, which can be a color, image, or gradient.